==> libgoose-0.0.4.tar.gz: libgoose-0.0.4/src/DataImport.h <==
// This is -*- C++ -*-
// $Id: DataImport.h,v 1.9 1998/09/28 16:21:00 hp Exp $

/* DataImport.h
 *
 * Copyright (C) 1998 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@emccta.com>.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef _INC_DATAIMPORT_H
#define _INC_DATAIMPORT_H

#include <algo.h>
#include <iostream.h>
#include <vector.h>
#include <string>
#include "DataSet.h"

class ColumnSpec {
public:
  ColumnSpec() : type_(0), label_("Untitled"), 
    sep_(""), ignore_(false), max_(0),
    has_max_(false) { }

  // Type to use for parsing and formatting
  const DataType* type() const { return type_; }

  // A label, possibly embedded in the file with some silly
  //  comment magic
  string label() const { return label_; }

  // Separator to expect *after* this column
  const string& separator() const { return sep_; }

  // Whether to ignore this column
  bool ignore() const { return ignore_; }

  // max elements to import
  size_t max_elements() const { return max_; }
  
  // ignore the max elements value
  bool   has_max() const { return has_max_; }

  void set_type(const DataType& t) { type_ = &t; }
  void set_label(const string& s) { label_ = s; }
  void set_separator(const string& s) { sep_ = s; }
  void set_ignore(bool b) { ignore_ = b; }
  void set_max_elements(size_t n) { max_ = n; }
  void set_has_max(bool b) { has_max_ = b; }

  string extract(const string& row);

private:
  const DataType* type_;
  string label_;
  string sep_;
  bool ignore_;
  size_t max_;
  bool has_max_;
};

class ImportEngine {
public:
  ImportEngine() : sep_("\n"), results_not_requested_(true) { }
  ~ImportEngine();

  // Set separator between rows; e.g. \r\n for DOS, \n for UNIX, or
  // whatever twisted thing fits someone's data.
  void set_separator(const string & s) { sep_ = s; }

  // Separator accessor
  const string& separator() const { return sep_; }

  // Load only after setting up the separators and columns - 
  //  load takes your parameters on faith.
  void load(istream & is); // will eventually do it on the fly; for now just stringifies.
  void load(const string & s);

  size_t column_count() const { return cols_.size(); }
  ColumnSpec* column(size_t i) { return cols_[i]; }
  void add_column(ColumnSpec* cs) { cols_.push_back(cs); }

  // Note that this does *not* delete the ColumnSpec
  void remove_column(ColumnSpec* cs) {
    vector<ColumnSpec*>::iterator i = find(cols_.begin(), cols_.end(), cs);
    if (i != cols_.end()) {
      cols_.erase(i);
    }
  }

  // Not implemented yet: should peek at the data and fill the ColumnSpec
  // data structures with reasonable default guesses
  void guess_columns(const string & text); 

  // Not yet implemented - return a data structure describing the 
  // parsing, for display to the user. e.g. show the first few rows
  // with the tokens the current settings would produce highlighted.
  // SomeDataStructure parse_info();

  // Return a vector of dynamically allocated DataSet that the 
  //  caller is obligated to delete.
  vector<DataSet*> import() { results_not_requested_ = false; return results_; }

protected:

private:
  vector<ColumnSpec*> cols_;

  vector<DataSet*> results_;

  string sep_;

  bool results_not_requested_;
};

#endif // _INC_DATAIMPORT_H

// $Id: DataImport.h,v 1.9 1998/09/28 16:21:00 hp Exp $

==> libgoose-0.0.5.tar.gz: libgoose-0.0.5/src/DataImport.h <==
// This is -*- C++ -*-
// $Id: DataImport.h,v 1.11 1998/12/15 20:56:32 trow Exp $

/* DataImport.h
 *
 * Copyright (C) 1998 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@emccta.com>.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef _INC_DATAIMPORT_H
#define _INC_DATAIMPORT_H

#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include "RealSet.h"

using namespace std;

class ColumnSpec {
public:
  ColumnSpec() : type_(0), label_("Untitled"), 
    sep_(""), ignore_(false), max_(0),
    has_max_(false) { }

  // Type to use for parsing and formatting
  const DataType* type() const { return type_; }

  // A label, possibly embedded in the file with some silly
  //  comment magic
  string label() const { return label_; }

  // Separator to expect *after* this column
  const string& separator() const { return sep_; }

  // Whether to ignore this column
  bool ignore() const { return ignore_; }

  // max elements to import
  size_t max_elements() const { return max_; }
  
  // ignore the max elements value
  bool   has_max() const { return has_max_; }

  void set_type(const DataType& t) { type_ = &t; }
  void set_label(const string& s) { label_ = s; }
  void set_separator(const string& s) { sep_ = s; }
  void set_ignore(bool b) { ignore_ = b; }
  void set_max_elements(size_t n) { max_ = n; }
  void set_has_max(bool b) { has_max_ = b; }

  string extract(const string& row);

private:
  const DataType* type_;
  string label_;
  string sep_;
  bool ignore_;
  size_t max_;
  bool has_max_;
};

class ImportEngine {
public:
  ImportEngine() : sep_("\n"), results_not_requested_(true) { }
  ~ImportEngine();

  // Set separator between rows; e.g. \r\n for DOS, \n for UNIX, or
  // whatever twisted thing fits someone's data.
  void set_separator(const string & s) { sep_ = s; }

  // Separator accessor
  const string& separator() const { return sep_; }

  // Load only after setting up the separators and columns - 
  //  load takes your parameters on faith.
  void load(istream & is); // will eventually do it on the fly; for now just stringifies.
  void load(const string & s);

  size_t column_count() const { return cols_.size(); }
  ColumnSpec* column(size_t i) { return cols_[i]; }
  void add_column(ColumnSpec* cs) { cols_.push_back(cs); }

  // Note that this does *not* delete the ColumnSpec
  void remove_column(ColumnSpec* cs) {
    vector<ColumnSpec*>::iterator i = find(cols_.begin(), cols_.end(), cs);
    if (i != cols_.end()) {
      cols_.erase(i);
    }
  }

  // Not implemented yet: should peek at the data and fill the ColumnSpec
  // data structures with reasonable default guesses
  void guess_columns(const string & text); 

  // Not yet implemented - return a data structure describing the 
  // parsing, for display to the user. e.g. show the first few rows
  // with the tokens the current settings would produce highlighted.
  // SomeDataStructure parse_info();

  // Return a vector of dynamically allocated RealSet that the 
  //  caller is obligated to delete.
  vector<RealSet*> import() { results_not_requested_ = false; return results_; }

protected:

private:
  vector<ColumnSpec*> cols_;

  vector<RealSet*> results_;

  string sep_;

  bool results_not_requested_;
};

#endif // _INC_DATAIMPORT_H

// $Id: DataImport.h,v 1.11 1998/12/15 20:56:32 trow Exp $
